import PostDetailsAdditionalPosts from '@/components/PostDetailsAdditionalPosts';
import PostDetailsAddress from '@/components/PostDetailsAddress';
import PostDetailsBreadcrumb from '@/components/PostDetailsBreadcrumb';
import PostDetailsLatestPostsFeed from '@/components/PostDetailsLatestPostsFeed';
import Image from 'next/image';

export const metadata = {
  title: 'Blog details',
  description: 'Description of the website',
};

async function getPostById(id) {
  const res = await fetch('https://jsonplaceholder.typicode.com/posts/' + id);
  return res.json();
}

async function getPosts() {
  const res = await fetch('https://jsonplaceholder.typicode.com/posts?_start=0&_limit=6');
  return res.json();
}

export default async function BlogDetailsPage({ params: { id } }) {
  const post = await getPostById(id);
  const additionalPosts = await getPosts();

  return (
    <main className='blog-details_main'>
      <article className='blog-details'>
        <section className='blog-details_hero'>
          <PostDetailsBreadcrumb title={post.title} />
          <Image
            src='/assets/anthony-delanoix-aDxmYZtYj7g-unsplash.jpg'
            alt='Post image mask'
            width={1200}
            height={400}
          />
          <section className='blog-details_hero-bottom-container'>
            <h1>{post.title}</h1>
            <PostDetailsAddress />
          </section>
        </section>
        <section className='blog-details_content'>
          <section>
            <p>{post.body}</p>
          </section>
          <PostDetailsLatestPostsFeed />
        </section>
      </article>
      <PostDetailsAdditionalPosts additionalPosts={additionalPosts} />
    </main>
  );
}
